pub struct Backup {
pub path: PathBuf,
pub serial_number: String,
pub device_name: String,
pub product_name: String,
pub backup_date: String,
pub backup_size: String,
pub encrypted: String,
}Expand description
Struct to store the backup information
This includes the path to the backup, serial number, device name, product name, backup date, backup size, and encryption status.
Fields
path: PathBufserial_number: Stringdevice_name: Stringproduct_name: Stringbackup_date: Stringbackup_size: Stringencrypted: StringAuto Trait Implementations
impl Freeze for Backup
impl RefUnwindSafe for Backup
impl Send for Backup
impl Sync for Backup
impl Unpin for Backup
impl UnwindSafe for Backup